@@ -1,20 +1,22 @@
 from actionpack.actions.call import Call
 from actionpack.actions.pipeline import Pipeline
 from actionpack.actions.make_request import MakeRequest
-from actionpack.actions.read_bytes import ReadBytes
+from actionpack.actions.read import Read
 from actionpack.actions.read_input import ReadInput
+from actionpack.actions.remove import Remove
 from actionpack.actions.retry_policy import RetryPolicy
 from actionpack.actions.serialization import Serialization
-from actionpack.actions.write_bytes import WriteBytes
+from actionpack.actions.write import Write
 
 
 __all__ = [
     'Call',
     'MakeRequest',
     'Pipeline',
-    'ReadBytes',
+    'Read',
     'ReadInput',
+    'Remove',
     'RetryPolicy',
     'Serialization',
-    'WriteBytes'
+    'Write',
 ]
